@@ -1,6 +1,6 @@
 package Rinci;
 
-our $VERSION = '1.1.41'; # VERSION
+our $VERSION = '1.1.42'; # VERSION
 
 1;
 # ABSTRACT: Language-neutral metadata for your code
@@ -9,7 +9,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -17,14 +17,7 @@ Rinci - Language-neutral metadata for your code
 
 =head1 VERSION
 
-version 1.1.41
-
-=head1 DESCRIPTION
-
-=head1 FUNCTIONS
-
-
-None are exported by default, but they are exportable.
+version 1.1.42
 
 =head1 HOMEPAGE
 
@@ -36,8 +29,7 @@ Source repository is at L<https://github.com/sharyanto/perl-Rinci>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Rinci>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Rinci>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
